@@ -3,6 +3,7 @@ from __future__ import annotations
 import datetime
 import os
 import time
+import traceback
 from pprint import pprint as pp
 from typing import Any, Optional
 
@@ -96,7 +97,13 @@ class TimeEvent:
         # self.start_time = datetime.datetime.strptime(st_time[:19], "%Y-%m-%dT%H:%M:%S")
         end_time = self._event["end"]["dateTime"]
         self.end_time = datetime.datetime.fromisoformat(end_time)
-        self.id = self._event["id"] + "::" + self.start_time.isoformat()
+        self.id = "::".join(
+            (
+                self._event["id"],
+                self.start_time.isoformat(),
+                self.get_video_url(),
+            )
+        )
 
     def __repr__(self):
         return (
@@ -127,9 +134,13 @@ class TimeEvent:
     def get_video_url(self) -> str:
         entry_points = self._event.get("conferenceData", {}).get("entryPoints", [])
         for entry_point in entry_points:
-            if entry_point["entryPointType"] == "video":
+            if entry_point.get("entryPointType", "") == "video":
                 return entry_point["uri"]
 
+        # Occasionally there are events with links that aren't categorized but have URIs...
+        for entry_point in entry_points:
+            if "entryPointType" not in entry_point and entry_point.get("uri"):
+                return entry_point.get("uri")
         return ""
 
     def has_declined(self) -> bool:
@@ -280,6 +291,10 @@ class GoogleCalDownloader:  # (QObject):
             except ValueError:
                 #  print("Invalid event", item.get("summary", "<No Title>"))
                 continue
+            except:
+                # Unknown error needs to be handled
+                print(traceback.format_exc())
+                continue
             result.append(event)
 
         return result
